@@ -1,11 +1,11 @@
 #!/usr/bin/perl
 # BEGIN_ICS_COPYRIGHT8 ****************************************
-# 
-# Copyright (c) 2015-2017, Intel Corporation
-# 
+#
+# Copyright (c) 2015-2020, Intel Corporation
+#
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
-# 
+#
 #     * Redistributions of source code must retain the above copyright notice,
 #       this list of conditions and the following disclaimer.
 #     * Redistributions in binary form must reproduce the above copyright
@@ -14,7 +14,7 @@
 #     * Neither the name of Intel Corporation nor the names of its contributors
 #       may be used to endorse or promote products derived from this software
 #       without specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
@@ -25,7 +25,7 @@
 # CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # END_ICS_COPYRIGHT8   ****************************************
 
 #[ICS VERSION STRING: unknown]
@@ -57,8 +57,7 @@ sub install_generic_mpi
     printf ("Installing $ComponentInfo{$mpifullname}{'Name'} $version...\n");
     LogPrint ("Installing $ComponentInfo{$mpifullname}{'Name'} $version for $CUR_OS_VER\n");
     # make sure any old potentially custom built versions of mpi are uninstalled
-    my @list = ( "$mpifullname", "mpitests_$mpifullname" );
-    rpm_uninstall_list2("any", "--nodeps", 'silent', @list);
+    uninstall_comp_rpms($mpifullname, ' --nodeps ', $install_list, $installing_list, 'silent');
 	# cleanup from older installs just in case
     system ("rm -rf /usr/lib/opa/.comp_$mpifullname.pl");
     
@@ -79,7 +78,7 @@ sub install_generic_mpi
     # enable this code if mpitests is missing for some compilers or MPIs
     #my $mpitests_rpmfile = rpm_resolve("$srcdir/OtherMPIs/mpitests_$mpifullname", "any");
     #if ( "$mpitests_rpmfile" ne "" && -e "$mpitests_rpmfile" ) {
-        rpm_install_list_with_options ("$srcdir", "user", " -U --nodeps ", @list);
+        install_comp_rpms($mpifullname, " -U --nodeps ", $install_list);
     #} else {
     #    rpm_install("$srcdir/OtherMPIs/$mpifullname", "user");
     #}
@@ -129,8 +128,7 @@ sub uninstall_generic_mpi
     }
     
     # uninstall tests in case built by do_build
-    $rc = rpm_uninstall ("mpitests_$mpifullname", "user", "", "verbose");
-    $rc = rpm_uninstall ($mpifullname, "user", "", "verbose");
+    uninstall_comp_rpms($mpifullname, '', $install_list, $installing_list, 'verbose');
 
 	# unfortunately mpi and mpitests can leave empty directories on uninstall
 	# this can confuse IFS MPI tools because correct MPI to use
@@ -159,6 +157,11 @@ sub uninstall_generic_mpi
 # is component X available on the install media (use of this
 # allows for optional components in packaging or limited availability if a
 # component isn't available on some OS/CPU combos)
+sub get_rpms_dir_openmpi_gcc
+{
+    return $ComponentInfo{'openmpi_gcc'}{'SrcDir'};
+}
+
 sub available_openmpi_gcc
 {
     my $srcdir = $ComponentInfo{'openmpi_gcc'}{'SrcDir'};
@@ -267,6 +270,12 @@ sub uninstall_openmpi_gcc
 # is component X available on the install media (use of this
 # allows for optional components in packaging or limited availability if a
 # component isn't available on some OS/CPU combos)
+
+sub get_rpms_dir_mvapich2_gcc
+{
+    return $ComponentInfo{'mvapich2_gcc'}{'SrcDir'};
+}
+
 sub available_mvapich2_gcc
 {
     my $srcdir = $ComponentInfo{'mvapich2_gcc'}{'SrcDir'};
@@ -375,6 +384,12 @@ sub uninstall_mvapich2_gcc
 # is component X available on the install media (use of this
 # allows for optional components in packaging or limited availability if a
 # component isn't available on some OS/CPU combos)
+
+sub get_rpms_dir_openmpi_gcc_hfi
+{
+    return $ComponentInfo{'openmpi_gcc_hfi'}{'SrcDir'};
+}
+
 sub available_openmpi_gcc_hfi
 {
     my $srcdir = $ComponentInfo{'openmpi_gcc_hfi'}{'SrcDir'};
@@ -483,6 +498,12 @@ sub uninstall_openmpi_gcc_hfi
 # is component X available on the install media (use of this
 # allows for optional components in packaging or limited availability if a
 # component isn't available on some OS/CPU combos)
+
+sub get_rpms_dir_openmpi_intel_hfi
+{
+    return $ComponentInfo{'openmpi_intel_hfi'}{'SrcDir'};
+}
+
 sub available_openmpi_intel_hfi
 {
     my $srcdir = $ComponentInfo{'openmpi_intel_hfi'}{'SrcDir'};
@@ -591,6 +612,12 @@ sub uninstall_openmpi_intel_hfi
 # is component X available on the install media (use of this
 # allows for optional components in packaging or limited availability if a
 # component isn't available on some OS/CPU combos)
+
+sub get_rpms_dir_openmpi_pgi_hfi
+{
+    return $ComponentInfo{'openmpi_pgi_hfi'}{'SrcDir'};
+}
+
 sub available_openmpi_pgi_hfi
 {
     my $srcdir = $ComponentInfo{'openmpi_pgi_hfi'}{'SrcDir'};
@@ -699,6 +726,12 @@ sub uninstall_openmpi_pgi_hfi
 # is component X available on the install media (use of this
 # allows for optional components in packaging or limited availability if a
 # component isn't available on some OS/CPU combos)
+
+sub get_rpms_dir_mvapich2_gcc_hfi
+{
+    return $ComponentInfo{'mvapich2_gcc_hfi'}{'SrcDir'};
+}
+
 sub available_mvapich2_gcc_hfi
 {
     my $srcdir = $ComponentInfo{'mvapich2_gcc_hfi'}{'SrcDir'};
@@ -807,6 +840,12 @@ sub uninstall_mvapich2_gcc_hfi
 # is component X available on the install media (use of this
 # allows for optional components in packaging or limited availability if a
 # component isn't available on some OS/CPU combos)
+
+sub get_rpms_dir_mvapich2_intel_hfi
+{
+    return $ComponentInfo{'mvapich2_intel_hfi'}{'SrcDir'};
+}
+
 sub available_mvapich2_intel_hfi
 {
     my $srcdir = $ComponentInfo{'mvapich2_intel_hfi'}{'SrcDir'};
@@ -916,6 +955,12 @@ sub uninstall_mvapich2_intel_hfi
 # is component X available on the install media (use of this
 # allows for optional components in packaging or limited availability if a
 # component isn't available on some OS/CPU combos)
+
+sub get_rpms_dir_mvapich2_pgi_hfi
+{
+    return $ComponentInfo{'mvapich2_pgi_hfi'}{'SrcDir'};
+}
+
 sub available_mvapich2_pgi_hfi
 {
     my $srcdir = $ComponentInfo{'mvapich2_pgi_hfi'}{'SrcDir'};
@@ -1028,6 +1073,12 @@ sub uninstall_mvapich2_pgi_hfi
 # is component X available on the install media (use of this
 # allows for optional components in packaging or limited availability if a
 # component isn't available on some OS/CPU combos)
+
+sub get_rpms_dir_openmpi_gcc_cuda_hfi
+{
+    return $ComponentInfo{'openmpi_gcc_cuda_hfi'}{'SrcDir'};
+}
+
 sub available_openmpi_gcc_cuda_hfi
 {
     my $srcdir = $ComponentInfo{'openmpi_gcc_cuda_hfi'}{'SrcDir'};
@@ -1142,7 +1193,7 @@ sub available_mpisrc()
 
 sub installed_mpisrc()
 {
-	my $srcdir = "/usr/src/opa/MPI";
+	my $srcdir = $ExtraMpisrcInfo{'Dest'};
 	my $old_srcdir = "/usr/lib/opa/src/MPI";
 	return (has_mpisrc($srcdir) || has_mpisrc($old_srcdir));
 }
@@ -1150,15 +1201,18 @@ sub installed_mpisrc()
 sub has_mpisrc($)
 {
 	my $srcdir = shift();
-	return (file_glob("$srcdir/mvapich*.src.rpm") ne ""
-	        && file_glob("$srcdir/openmpi*.src.rpm") ne ""
-	        && file_glob("$srcdir/mpitests*.src.rpm") ne "");
+	foreach my $srpm (@{$ExtraMpisrcInfo{'SrcRpms'}}) {
+		if (file_glob("$srcdir/${srpm}*.src.rpm") eq "") {
+			return 0;
+		}
+	}
+	return 1;
 }
 
 # only called if installed_mpisrc is true
 sub installed_version_mpisrc()
 {
-	return `cat /usr/src/opa/MPI/.version`;
+	return `cat $ExtraMpisrcInfo{'Dest'}/.version`;
 }
 
 # only called if available_mpisrc is true
@@ -1204,36 +1258,41 @@ sub install_mpisrc($$)
 	my $installing_list = shift();	# what items are being installed/reinstalled
 
 	my $srcdir=$ComponentInfo{'mpisrc'}{'SrcDir'};
-    my $version = media_version_mpisrc();
-    chomp $version;
+	my $version = media_version_mpisrc();
+	chomp $version;
 
-    printf ("Installing $ComponentInfo{'mpisrc'}{'Name'} $version...\n");
-    LogPrint ("Installing $ComponentInfo{'mpisrc'}{'Name'} $version for $CUR_OS_VER\n");
+	printf ("Installing $ComponentInfo{'mpisrc'}{'Name'} $version...\n");
+	LogPrint ("Installing $ComponentInfo{'mpisrc'}{'Name'} $version for $CUR_OS_VER\n");
 
-	check_dir("/usr/src/opa");
-	check_dir("/usr/src/opa/MPI");
+	my $destdir = $ExtraMpisrcInfo{'Dest'};
+	check_dir($destdir);
 	# remove old versions (.src.rpm and built .rpm files too)
-	system "rm -rf /usr/src/opa/MPI/mvapich[-_]*.rpm 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/mvapich2[-_]*.rpm 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/openmpi[-_]*.rpm 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/mpitests[-_]*.rpm 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/make.*.res 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/make.*.err 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/make.*.warn 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/.mpiinfo 2>/dev/null";
+	system "rm -f $destdir/mvapich[-_]*.rpm 2>/dev/null";
+	foreach my $srpm (@{$ExtraMpisrcInfo{'SrcRpms'}})
+	{
+		system "rm -f $destdir/$srpm-*.rpm 2>/dev/null";
+	}
+	foreach my $file (@{$ExtraMpisrcInfo{'DirtyFiles'}})
+	{
+		system "rm -f $destdir/$file 2>/dev/null";
+	}
 
 	# install new versions
-	foreach my $srpm ( "mvapich2", "openmpi", "mpitests" ) {
+	foreach my $srpm (@{$ExtraMpisrcInfo{'SrcRpms'}}) {
 		my $srpmfile = file_glob("$srcdir/${srpm}-*.src.rpm");
 		if ( "$srpmfile" ne "" ) {
 			my $file = my_basename($srpmfile);
-			copy_data_file($srpmfile, "/usr/src/opa/MPI/$file");
+			copy_data_file($srpmfile, "$destdir/$file");
 		}
 	}
-	copy_systool_file("$srcdir/do_build", "/usr/src/opa/MPI/do_build");
-	copy_systool_file("$srcdir/do_mvapich2_build", "/usr/src/opa/MPI/do_mvapich2_build");
-	copy_systool_file("$srcdir/do_openmpi_build", "/usr/src/opa/MPI/do_openmpi_build");
-	copy_data_file("$srcdir/version", "/usr/src/opa/MPI/.version");
+	foreach my $script (@{$ExtraMpisrcInfo{'BuildScripts'}}) {
+		copy_systool_file("$srcdir/$script", "$destdir/$script");
+	}
+	foreach my $file (@{$ExtraMpisrcInfo{'MiscFiles'}}) {
+		my $src = ${$file}{'Src'};
+		my $dest = ${$file}{'Dest'};
+		copy_data_file("$srcdir/$src", "$destdir/$dest");
+	}
 
 	$ComponentWasInstalled{'mpisrc'}=1;
 }
@@ -1249,23 +1308,32 @@ sub uninstall_mpisrc($$)
 	my $install_list = shift();	# total that will be left installed when done
 	my $uninstalling_list = shift();	# what items are being uninstalled
 
-    NormalPrint ("Uninstalling $ComponentInfo{'mpisrc'}{'Name'}...\n");
+	NormalPrint ("Uninstalling $ComponentInfo{'mpisrc'}{'Name'}...\n");
 
-	# remove old versions (.src.rpm and built .rpm files too)
-	system "rm -rf /usr/src/opa/MPI/.version 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/mvapich2[-_]*.rpm 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/openmpi[-_]*.rpm 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/mpitests[-_]*.rpm 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/make.*.res 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/make.*.err 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/make.*.warn 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/.mpiinfo 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/do_build 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/do_mvapich2_build 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/do_openmpi_build 2>/dev/null";
-	system "rm -rf /usr/src/opa/MPI/.mpiinfo 2>/dev/null";
+	# try to uninstall meta pkg if it exists
+	if (rpm_is_installed("opameta_mpisrc", "any") ||
+	    rpm_is_installed("opameta_mpisrc_userspace", "any")) {
+		rpm_uninstall_matches("opameta_mpisrc", "opameta_mpisrc", "", "");
+	} else {
+		my $destdir = $ExtraMpisrcInfo{'Dest'};
+		# remove old versions (.src.rpm and built .rpm files too)
+		foreach my $srpm (@{$ExtraMpisrcInfo{'SrcRpms'}}) {
+			system "rm -f $destdir/$srpm-*.rpm 2>/dev/null";
+		}
+		foreach my $script (@{$ExtraMpisrcInfo{'BuildScripts'}}) {
+			system "rm -f $destdir/$script 2>/dev/null";
+		}
+		foreach my $file (@{$ExtraMpisrcInfo{'MiscFiles'}}) {
+			my $destfile = ${$file}{'Dest'};
+			system "rm -f $destdir/$destfile 2>/dev/null";
+		}
+		foreach my $file (@{$ExtraMpisrcInfo{'DirtyFiles'}}) {
+			system "rm -f $destdir/$file 2>/dev/null";
+		}
+
+		system "rmdir $destdir 2>/dev/null"; # remove only if empty
+		system "rmdir /usr/src/opa 2>/dev/null"; # remove only if empty
+	}
 
-	system "rmdir /usr/src/opa/MPI 2>/dev/null"; # remove only if empty
-	system "rmdir /usr/src/opa 2>/dev/null"; # remove only if empty
 	$ComponentWasInstalled{'mpisrc'}=0;
 }
