@@ -1,11 +1,11 @@
 #!/bin/bash
 # BEGIN_ICS_COPYRIGHT8 ****************************************
-# 
-# Copyright (c) 2015-2018, Intel Corporation
-# 
+#
+# Copyright (c) 2015-2020, Intel Corporation
+#
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
-# 
+#
 #     * Redistributions of source code must retain the above copyright notice,
 #       this list of conditions and the following disclaimer.
 #     * Redistributions in binary form must reproduce the above copyright
@@ -14,7 +14,7 @@
 #     * Neither the name of Intel Corporation nor the names of its contributors
 #       may be used to endorse or promote products derived from this software
 #       without specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
@@ -25,7 +25,7 @@
 # CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # END_ICS_COPYRIGHT8   ****************************************
 
 # This file incorporates work covered by the following copyright and permission notice 
@@ -65,6 +65,9 @@ VERSION_ID=""
 
 if [ -e /etc/os-release ]; then
     . /etc/os-release
+    if [[ "$ID" == "sle_hpc" ]]; then
+        ID="sles"
+    fi
 else
     echo /etc/os-release is not available !!!
 fi
@@ -511,7 +514,7 @@ logfile=make.mvapich2.$interface.$compiler
 				mvapich2_comp_env='CC="gcc -m64" CXX="g++ -m64" F77="gfortran -m64" FC="gfortran -m64"'
 			else
 				mvapich2_comp_env='CC=gcc CXX=g++ F77=gfortran FC=gfortran'
-				if [[ ( "$ID" == "rhel"  &&  $(echo "$VERSION_ID == 8.0" | bc -l) == 1 ) ]]; then
+				if [[ ( "$ID" == "rhel"  &&  $(echo "$VERSION_ID >= 8.0" | bc -l) == 1 ) ]]; then
 					mvapich2_comp_env="$mvapich2_comp_env CFLAGS='-fPIC'"
 				fi
 			fi
@@ -521,7 +524,7 @@ logfile=make.mvapich2.$interface.$compiler
 				mvapich2_comp_env='CC="gcc -m64" CXX="g++ -m64" F77="g77 -m64" FC="/bin/false"'
 			else
 				mvapich2_comp_env='CC=gcc CXX=g++ F77=g77 FC=/bin/false'
-				if [[ ( "$ID" == "rhel"  &&  $(echo "$VERSION_ID == 8.0" | bc -l) == 1 ) ]]; then
+				if [[ ( "$ID" == "rhel"  &&  $(echo "$VERSION_ID >= 8.0" | bc -l) == 1 ) ]]; then
 					mvapich2_comp_env="$mvapich2_comp_env CFLAGS='-fPIC'"
 				fi
 			fi
