@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # BEGIN_ICS_COPYRIGHT8 ****************************************
 #
-# Copyright (c) 2015-2017, Intel Corporation
+# Copyright (c) 2015-2020, Intel Corporation
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -44,6 +44,7 @@ my $Build_Debug=0;	# should we provide more info for debug
 my $Build_Temp="";	# temp area to use for build
 my $Default_Build = 0;	# -B option used to select build
 my $Build_Force = 0;# rebuild option used to force full rebuild
+my $To_Show_Comps = 0; # indicate whether we need to show components or not
 
 $FirstIPoIBInterface=0; # first device is ib0
 
@@ -56,7 +57,7 @@ my @OmniPathAllComponents = (
 	"delta_ipoib", "opafm", "opamgt_sdk",
 	"mvapich2_gcc_hfi", "mvapich2_intel_hfi",
 	"openmpi_gcc_hfi", "openmpi_intel_hfi",
-	"openmpi_gcc_cuda_hfi", "sandiashmem",
+	"openmpi_gcc_cuda_hfi",
 	"mvapich2_gcc",	"openmpi_gcc", #"mpiRest",
 	"mpisrc", "delta_debug"	);
 
@@ -70,18 +71,30 @@ my @Components_sles12_sp3 = ( "opa_stack",
 		@OmniPathAllComponents );
 my @Components_sles12_sp4 = ( "opa_stack",
 		@OmniPathAllComponents );
+my @Components_sles12_sp5 = ( "opa_stack",
+		@OmniPathAllComponents );
 my @Components_sles15 = ( "opa_stack",
 		@OmniPathAllComponents );
 my @Components_sles15_sp1 = ( "opa_stack",
 		@OmniPathAllComponents );
+my @Components_sles15_sp2 = ( "opa_stack",
+		@OmniPathAllComponents );
 my @Components_rhel74 = ( "opa_stack", "mpi_selector",
 		@OmniPathAllComponents );
 my @Components_rhel75 = ( "opa_stack", "mpi_selector",
 		@OmniPathAllComponents );
 my @Components_rhel76 = ( "opa_stack", "mpi_selector",
 		@OmniPathAllComponents );
+my @Components_rhel77 = ( "opa_stack", "mpi_selector",
+		@OmniPathAllComponents );
+my @Components_rhel78 = ( "opa_stack", "mpi_selector",
+		@OmniPathAllComponents );
 my @Components_rhel8 = ( "opa_stack", "mpi_selector",
 		@OmniPathAllComponents );
+my @Components_rhel81 = ( "opa_stack", "mpi_selector",
+		@OmniPathAllComponents );
+my @Components_rhel82 = ( "opa_stack", "mpi_selector",
+		@OmniPathAllComponents );
 
 @Components = ( );
 
@@ -198,7 +211,7 @@ $WrapperComponent = "opaconfig";
 					  Hidden => 0, Disabled => 0, IsOFA => 0,
 					  KernelRpms => [ ],
 					  FirmwareRpms => [ ],
-					  UserRpms => [ ],
+					  UserRpms => [ "opa-basic-tools", "opa-address-resolution" ],
 					  DebugRpms => [ ],
 					  HasStart => 1, HasFirmware => 0, DefaultStart => 0,
 					  StartPreReq => " opa_stack ", # TBD
@@ -228,7 +241,7 @@ $WrapperComponent = "opaconfig";
 					  Hidden => 0, Disabled => 0, IsOFA => 0,
 					  KernelRpms => [ ],
 					  FirmwareRpms => [ ],
-					  UserRpms => [ ],
+					  UserRpms => [ "opa-fastfabric", "opa-mpi-apps" ],
 					  DebugRpms => [ ],
 					  HasStart => 0, HasFirmware => 0, DefaultStart => 0,
 					  StartPreReq => " opa_stack ",
@@ -259,7 +272,7 @@ $WrapperComponent = "opaconfig";
 					  Hidden => 1, Disabled => 0, IsOFA => 0,
 					  KernelRpms => [ ],
 					  FirmwareRpms => [ ],
-					  UserRpms => [ ],
+					  UserRpms => [ "mvapich2_gcc", "mpitests_mvapich2_gcc" ],
 					  DebugRpms => [ ],
 					  HasStart => 0, HasFirmware => 0, DefaultStart => 0,
 					  StartPreReq => "",
@@ -274,26 +287,7 @@ $WrapperComponent = "opaconfig";
 					  Hidden => 1, Disabled => 0, IsOFA => 0,
 					  KernelRpms => [ ],
 					  FirmwareRpms => [ ],
-					  UserRpms => [ ],
-					  DebugRpms => [ ],
-					  HasStart => 0, HasFirmware => 0, DefaultStart => 0,
-					  StartPreReq => "",
-					  StartComponents => [ ],
-					  StartupScript => "",
-					  StartupParams => [ ]
-					},
-	"sandiashmem" =>	{ Name => "Sandia-OpenSHMEM ",
-					  DefaultInstall => $State_Install,
-					  SrcDir => file_glob("./IntelOPA-OFA_DELTA.*"),
-					  PreReq => " opa_stack intel_hfi ", CoReq => "",
-# TBD - should IsOFA be 0?
-					  Hidden => 0, Disabled => 0, IsOFA => 1,
-					  KernelRpms => [ ],
-					  FirmwareRpms => [ ],
-					  UserRpms => [ "sandia-openshmem_gcc_hfi",
-									"sandia-openshmem_gcc_hfi-devel",
-									"sandia-openshmem_gcc_hfi-tests"
-								],
+					  UserRpms => [ "openmpi_gcc", "mpitests_openmpi_gcc" ],
 					  DebugRpms => [ ],
 					  HasStart => 0, HasFirmware => 0, DefaultStart => 0,
 					  StartPreReq => "",
@@ -305,10 +299,10 @@ $WrapperComponent = "opaconfig";
 					  DefaultInstall => $State_Install,
 					  SrcDir => file_glob ("./OFA_MPIS.*"),
 					  PreReq => " opa_stack intel_hfi mpi_selector ", CoReq => "",
-					  Hidden => 0, Disabled => 0, IsOFA => 0,
+					  Hidden => 1, Disabled => 1, IsOFA => 0,
 					  KernelRpms => [ ],
 					  FirmwareRpms => [ ],
-					  UserRpms => [ ],
+					  UserRpms => [ "openmpi_gcc_cuda_hfi", "mpitests_openmpi_gcc_cuda_hfi" ],
 					  DebugRpms => [ ],
 					  HasStart => 0, HasFirmware => 0, DefaultStart => 0,
 					  StartPreReq => "",
@@ -323,7 +317,7 @@ $WrapperComponent = "opaconfig";
 					  Hidden => 0, Disabled => 0, IsOFA => 0,
 					  KernelRpms => [ ],
 					  FirmwareRpms => [ ],
-					  UserRpms => [ ],
+					  UserRpms => [ "mvapich2_gcc_hfi", "mpitests_mvapich2_gcc_hfi" ],
 					  DebugRpms => [ ],
 					  HasStart => 0, HasFirmware => 0, DefaultStart => 0,
 					  StartPreReq => "",
@@ -338,7 +332,7 @@ $WrapperComponent = "opaconfig";
 					  Hidden => 1, Disabled => 0, IsOFA => 0,
 					  KernelRpms => [ ],
 					  FirmwareRpms => [ ],
-					  UserRpms => [ ],
+					  UserRpms => [ "mvapich2_intel_hfi", "mpitests_mvapich2_intel_hfi" ],
 					  DebugRpms => [ ],
 					  HasStart => 0, HasFirmware => 0, DefaultStart => 0,
 					  StartPreReq => "",
@@ -353,7 +347,7 @@ $WrapperComponent = "opaconfig";
 					  Hidden => 0, Disabled => 0, IsOFA => 0,
 					  KernelRpms => [ ],
 					  FirmwareRpms => [ ],
-					  UserRpms => [ ],
+					  UserRpms => [ "openmpi_gcc_hfi", "mpitests_openmpi_gcc_hfi" ],
 					  DebugRpms => [ ],
 					  HasStart => 0, HasFirmware => 0, DefaultStart => 0,
 					  StartPreReq => "",
@@ -368,7 +362,7 @@ $WrapperComponent = "opaconfig";
 					  Hidden => 1, Disabled => 0, IsOFA => 0,
 					  KernelRpms => [ ],
 					  FirmwareRpms => [ ],
-					  UserRpms => [ ],
+					  UserRpms => [ "openmpi_intel_hfi", "mpitests_openmpi_intel_hfi" ],
 					  DebugRpms => [ ],
 					  HasStart => 0, HasFirmware => 0, DefaultStart => 0,
 					  StartPreReq => "",
@@ -443,7 +437,7 @@ $WrapperComponent = "opaconfig";
 					  Hidden => 0, Disabled => 0, IsOFA => 0,
 					  KernelRpms => [ ],
 					  FirmwareRpms => [ ],
-					  UserRpms => [ ],
+					  UserRpms => [ "opa-fm", "opa-fm-debuginfo" ],
 					  DebugRpms => [ ],
 					  HasStart => 1, HasFirmware => 0, DefaultStart => 0,
 					  StartPreReq => " opa_stack ",
@@ -459,7 +453,7 @@ $WrapperComponent = "opaconfig";
 					  Hidden => 0, Disabled => 0, IsOFA => 0,
 					  KernelRpms => [ ],
 					  FirmwareRpms => [ ],
-					  UserRpms => [ ],
+					  UserRpms => [ "opa-libopamgt", "opa-libopamgt-devel" ],
 					  DebugRpms => [ ],
 					  HasStart => 0, HasFirmware => 0, DefaultStart => 0,
 					  StartPreReq => " opa_stack ",
@@ -514,6 +508,29 @@ $WrapperComponent = "opaconfig";
 					},
 	);
 
+# We can improve ComponentInfo to include the following. But since they are used
+# for mpisrc only, extending ComponentInfo doesn't benefit other components.
+# We directly define them here where
+#     Dest => installation location
+#     SrcRpms => src rpms to install
+#     BuildScripts => build script to install
+#     MiscFiles => misc files, such as version file. This field includes 'Dest'
+#                  and 'Src' to define the installed file name and source file
+#                  name. For SrcRpms and BuildScript fields, the installed file
+#                  name will be the same name as source file.
+#     DirtyFiles => dirty files will be cleared during install/uninstall, such
+#                   as the build generated files.
+%ExtraMpisrcInfo = (
+	Dest => "/usr/src/opa/MPI",
+	SrcRpms => ["mvapich2", "openmpi", "mpitests"],
+	BuildScripts => ["do_build", "do_mvapich2_build", "do_openmpi_build"],
+	MiscFiles => [{
+		Dest => ".version",
+		Src => "version"}],
+	DirtyFiles => [ "{mvapich2,openmpi,mpitests}_*.rpm",
+	                "make.*.{res,err,warn}", ".mpiinfo"]
+);
+
 # one of these opa_stack comp_info gets appended to ComponentInfo
 # for RHEL72
 my %opa_stack_rhel72_comp_info = (
@@ -688,6 +705,26 @@ my %opa_stack_sles12_sp4_comp_info = (
 					},
 );
 
+# for SLES12sp5
+my %opa_stack_sles12_sp5_comp_info = (
+	"opa_stack" =>	{ Name => "OFA OPA Stack",
+					  DefaultInstall => $State_Install,
+					  SrcDir => file_glob("./IntelOPA-OFA_DELTA.*"),
+					  PreReq => "", CoReq => " oftools ",
+					  Hidden => 0, Disabled => 0, IsOFA => 1,
+					  KernelRpms => [ "ifs-kernel-updates-kmp-default" ],
+					  FirmwareRpms => [ ],
+					  UserRpms => [ "opa-scripts",
+								],
+					  DebugRpms => [ ],
+					  HasStart => 1, HasFirmware => 0, DefaultStart => 1,
+					  StartPreReq => "",
+					  StartComponents => [ "opa_stack", "ibacm", "rdma_ndd", "delta_srp", "delta_srpt" ],
+					  StartupScript => "opa",
+					  StartupParams => [ "ARPTABLE_TUNING" ]
+					},
+);
+
 # for SLES15.x
 my %opa_stack_sles15_comp_info = (
 	"opa_stack" =>	{ Name => "OFA OPA Stack",
@@ -845,6 +882,66 @@ my %intel_hfi_rhel8_comp_info = (
 					},
 );
 
+my %intel_hfi_rhel81_comp_info = (
+	"intel_hfi" =>	{ Name => "Intel HFI Components",
+					  DefaultInstall => $State_Install,
+					  SrcDir => file_glob("./IntelOPA-OFA_DELTA.*"),
+					  PreReq => " opa_stack ", CoReq => " oftools ",
+						# TBD - HasFirmware - FW update
+					  Hidden => 0, Disabled => 0, IsOFA => 1,
+					  KernelRpms => [ ],
+					  FirmwareRpms => [
+									"hfi1-firmware", "hfi1-firmware_debug"
+								],
+					  UserRpms => [ #"libhfi1", "libhfi1-static",
+									"libpsm2",
+									"libpsm2-devel", "libpsm2-compat",
+									"libfabric", "libfabric-devel",
+									"libfabric-psm2", "libfabric-verbs",
+									"hfi1-diagtools-sw", "hfidiags",
+								],
+					  DebugRpms =>  [ #"hfi1_debuginfo",
+									"hfi1-diagtools-sw-debuginfo",
+									"libpsm2-debuginfo", #"libhfi1-debuginfo"
+								],
+					  HasStart => 1, HasFirmware => 0, DefaultStart => 1,
+					  StartPreReq => " opa_stack ",
+					  StartComponents => [ "intel_hfi" ],
+					  StartupScript => "",
+					  StartupParams => [ ]
+					},
+);
+
+my %intel_hfi_rhel82_comp_info = (
+	"intel_hfi" =>	{ Name => "Intel HFI Components",
+					  DefaultInstall => $State_Install,
+					  SrcDir => file_glob("./IntelOPA-OFA_DELTA.*"),
+					  PreReq => " opa_stack ", CoReq => " oftools ",
+						# TBD - HasFirmware - FW update
+					  Hidden => 0, Disabled => 0, IsOFA => 1,
+					  KernelRpms => [ ],
+					  FirmwareRpms => [
+									"hfi1-firmware", "hfi1-firmware_debug"
+								],
+					  UserRpms => [ #"libhfi1", "libhfi1-static",
+									"libpsm2",
+									"libpsm2-devel", "libpsm2-compat",
+									"libfabric", "libfabric-devel",
+									"libfabric-psm2", "libfabric-verbs",
+									"hfi1-diagtools-sw", "hfidiags",
+								],
+					  DebugRpms =>  [ #"hfi1_debuginfo",
+									"hfi1-diagtools-sw-debuginfo",
+									"libpsm2-debuginfo", #"libhfi1-debuginfo"
+								],
+					  HasStart => 1, HasFirmware => 0, DefaultStart => 1,
+					  StartPreReq => " opa_stack ",
+					  StartComponents => [ "intel_hfi" ],
+					  StartupScript => "",
+					  StartupParams => [ ]
+					},
+);
+
 # For SLES12sp3 that has different name for libpsm2
 my %intel_hfi_sles123_comp_info = (
 	"intel_hfi" =>	{ Name => "Intel HFI Components",
@@ -905,6 +1002,34 @@ my %intel_hfi_sles124_comp_info = (
 					},
 );
 
+my %intel_hfi_sles125_comp_info = (
+	"intel_hfi" =>	{ Name => "Intel HFI Components",
+					  DefaultInstall => $State_Install,
+					  SrcDir => file_glob("./IntelOPA-OFA_DELTA.*"),
+					  PreReq => " opa_stack ", CoReq => " oftools ",
+					  Hidden => 0, Disabled => 0, IsOFA => 1,
+					  KernelRpms => [ ],
+					  FirmwareRpms => [
+									"hfi1-firmware", "hfi1-firmware_debug"
+								],
+					  UserRpms => [ 		"libpsm2-2",
+									"libpsm2-devel", "libpsm2-compat",
+									"libfabric", "libfabric-devel",
+									"libfabric-psm",
+									"libfabric-psm2", "libfabric-verbs",
+									"hfi1-diagtools-sw", "hfidiags",
+								],
+					  DebugRpms =>  [ 		"hfi1-diagtools-sw-debuginfo",
+									"libpsm2-debuginfo", 
+								],
+					  HasStart => 1, HasFirmware => 0, DefaultStart => 1,
+					  StartPreReq => " opa_stack ",
+					  StartComponents => [ "intel_hfi" ],
+					  StartupScript => "",
+					  StartupParams => [ ]
+					},
+);
+
 # For SLES15.x that has different name for libpsm2
 my %intel_hfi_sles15_comp_info = (
 	"intel_hfi" =>	{ Name => "Intel HFI Components",
@@ -1042,7 +1167,6 @@ my %opa_stack_dev_comp_info = (
 				"rdma_ndd" => 0,
 				"delta_srp" => 0,
 				"delta_srpt" => 0,
-				"sandiashmem" => 0,
 			);
 
 # check whether we support HFI2
@@ -1108,6 +1232,14 @@ sub init_components
 						%opa_stack_dev_comp_info,
 						%opa_stack_sles12_sp4_comp_info,
 						);
+	} elsif ( "$CUR_VENDOR_VER" eq "ES125" ) {
+		@Components = ( @Components_sles12_sp5 );
+		@SubComponents = ( @SubComponents_newer );
+		%ComponentInfo = ( %ComponentInfo, %ibacm_comp_info,
+						%intel_hfi_sles125_comp_info,
+						%opa_stack_dev_comp_info,
+						%opa_stack_sles12_sp5_comp_info,
+						);
 	} elsif ( "$CUR_VENDOR_VER" eq "ES74" ) {
 		@SubComponents = ( @SubComponents_newer );
 		@Components = ( @Components_rhel74 );
@@ -1140,6 +1272,22 @@ sub init_components
 						%opa_stack_dev_comp_info,
 						%opa_stack_rhel_comp_info,
 						);
+	} elsif ( "$CUR_VENDOR_VER" eq "ES77" ) {
+		@Components = ( @Components_rhel77 );
+		@SubComponents = ( @SubComponents_newer );
+		%ComponentInfo = ( %ComponentInfo, %ibacm_comp_info,
+						%intel_hfi_comp_info,
+						%opa_stack_dev_comp_info,
+						%opa_stack_rhel_comp_info,
+						);
+	} elsif ( "$CUR_VENDOR_VER" eq "ES78" ) {
+		@Components = ( @Components_rhel78 );
+		@SubComponents = ( @SubComponents_newer );
+		%ComponentInfo = ( %ComponentInfo, %ibacm_comp_info,
+						%intel_hfi_comp_info,
+						%opa_stack_dev_comp_info,
+						%opa_stack_rhel_comp_info,
+						);
 	} elsif ( "$CUR_VENDOR_VER" eq "ES8" ) {
 		@Components = ( @Components_rhel8 );
 		@SubComponents = ( @SubComponents_newer );
@@ -1148,6 +1296,22 @@ sub init_components
 						%opa_stack_dev_comp_info,
 						%opa_stack_rhel_comp_info,
 						);
+	} elsif ( "$CUR_VENDOR_VER" eq "ES81" ) {
+		@Components = ( @Components_rhel81 );
+		@SubComponents = ( @SubComponents_newer );
+		%ComponentInfo = ( %ComponentInfo, %ibacm_comp_info,
+						%intel_hfi_rhel81_comp_info,
+						%opa_stack_dev_comp_info,
+						%opa_stack_rhel_comp_info,
+						);
+	} elsif ( "$CUR_VENDOR_VER" eq "ES82" ) {
+		@Components = ( @Components_rhel82 );
+		@SubComponents = ( @SubComponents_newer );
+		%ComponentInfo = ( %ComponentInfo, %ibacm_comp_info,
+						%intel_hfi_rhel82_comp_info,
+						%opa_stack_dev_comp_info,
+						%opa_stack_rhel_comp_info,
+						);
 	} elsif ( "$CUR_VENDOR_VER" eq "ES15" ) {
 		@Components = ( @Components_sles15 );
 		@SubComponents = ( @SubComponents_newer );
@@ -1164,6 +1328,14 @@ sub init_components
 						%opa_stack_dev_comp_info,
 						%opa_stack_sles15_comp_info,
 						);
+	} elsif ( "$CUR_VENDOR_VER" eq "ES152" ) {
+		@Components = ( @Components_sles15_sp2 );
+		@SubComponents = ( @SubComponents_newer );
+		%ComponentInfo = ( %ComponentInfo, %ibacm_comp_info,
+						%intel_hfi_sles15_comp_info,
+						%opa_stack_dev_comp_info,
+						%opa_stack_sles15_comp_info,
+						);
 	} else {
 		# unknown or unsupported distro, leave lists empty
 		# verify_distrib_files will catch unsupported distro
@@ -1241,6 +1413,9 @@ sub install_opaconfig
 	my $srcdir=$ComponentInfo{'opaconfig'}{'SrcDir'};
 	NormalPrint("Installing $ComponentInfo{'opaconfig'}{'Name'}...\n");
 
+	# all meta pkgs depend on opaconfig. We may directly upgrade opaconfig, so we remove them first.
+	rpm_uninstall_matches("opameta_", "opameta_", "", "");
+
 	# New Install Code
 	my $rpmfile = rpm_resolve("$srcdir/RPMS/*/opaconfig", "any");
 	rpm_run_install($rpmfile, "any", " -U ");
@@ -1273,6 +1448,9 @@ sub uninstall_opaconfig
 
 	NormalPrint("Uninstalling $ComponentInfo{'opaconfig'}{'Name'}...\n");
 
+	# all meta pkgs depend on opaconfig. Remove them first.
+	rpm_uninstall_matches("opameta_", "opameta_", "", "");
+
 	# New Uninstall Code
 	rpm_uninstall_list("any", "verbose", ("opaconfig") );
 	# New Uninstall Code
@@ -1364,6 +1542,8 @@ sub Usage
 	printf STDERR "       -v - verbose logging\n";
 	printf STDERR "       -vv - very verbose debug logging\n";
 	printf STDERR "       -C - output list of supported components\n";
+#       Hidden feature for internal use
+#       printf STDERR "       -c comp - output component information in JSON format\n";
 	printf STDERR "       -V - output Version\n";
 
 	printf STDERR "       --user_queries - permit non-root users to query the fabric. (default)\n";
@@ -1406,8 +1586,6 @@ sub translate_comp
 		return ( "mvapich2_gcc_hfi","openmpi_gcc_hfi");
 	} elsif ("$arg" eq "psm_mpi"){
 		return ( "mvapich2_gcc_hfi","openmpi_gcc_hfi");
-	} elsif ("$arg" eq "pgas"){
-	        return ( "sandiashmem" );
 	} elsif ("$arg" eq "delta_mpisrc"){
 		return ( "mpisrc" ); # legacy
 		# no ibaccess argument equivalent for:
@@ -1597,10 +1775,15 @@ sub process_args
 					Usage;
 				} else {
 					$GPU_Install=1;
+					$ComponentInfo{"openmpi_gcc_cuda_hfi"}{'Hidden'} = 0;
+					$ComponentInfo{"openmpi_gcc_cuda_hfi"}{'Disabled'} = 0;
 				}
 			} elsif ( "$arg" eq "-C" ) {
-				ShowComponents;
-				exit(0);
+				$To_Show_Comps = 1;
+			} elsif ( "$arg" eq "-c" ) {
+				# undocumented option to output detailed information on a component
+				$Default_ShowCompInfo=1;
+				$setcomp=1;
 			} elsif ( "$arg" eq "-V" ) {
 				printf "$VERSION\n";
 				exit(0);
@@ -1684,6 +1867,11 @@ sub process_args
 			$last_arg=$arg;
 		}
 	}
+
+	if ($To_Show_Comps == 1) {
+		ShowComponents;
+		exit(0);
+	}
 	if ( $setcomp || $setenabled || $setdisabled  || $setosver || $setbuildtemp || $setfwmode || $setanswer) {
 		printf STDERR "Missing argument for option: $last_arg\n";
 		Usage;
@@ -1789,6 +1977,11 @@ overrides;
 
 process_args;
 check_root_user;
+if ( $Default_ShowCompInfo )
+{
+        ShowCompInfo();
+        exit(0);
+}
 if ( ! $Default_Build ) {
 	open_log("");
 } else {
