@@ -1,11 +1,11 @@
 #!/usr/bin/perl
 # BEGIN_ICS_COPYRIGHT8 ****************************************
-# 
-# Copyright (c) 2015-2017, Intel Corporation
-# 
+#
+# Copyright (c) 2015-2020, Intel Corporation
+#
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
-# 
+#
 #     * Redistributions of source code must retain the above copyright notice,
 #       this list of conditions and the following disclaimer.
 #     * Redistributions in binary form must reproduce the above copyright
@@ -14,7 +14,7 @@
 #     * Neither the name of Intel Corporation nor the names of its contributors
 #       may be used to endorse or promote products derived from this software
 #       without specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
@@ -25,7 +25,7 @@
 # CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # END_ICS_COPYRIGHT8   ****************************************
 
 # [ICS VERSION STRING: unknown]
@@ -41,57 +41,70 @@ use strict;
 my @delta_Components_rhel72 = ( "opa_stack", "ibacm", "mpi_selector", "intel_hfi",
 		"opa_stack_dev",
 		"delta_ipoib",
-		"sandiashmem",
 		"delta_debug", );
 my @delta_Components_sles12_sp2 = ( "opa_stack", "intel_hfi",
 		"opa_stack_dev",
 		"delta_ipoib",
-		"sandiashmem",
 		"delta_debug", );
 my @delta_Components_rhel73 = ( "opa_stack", "mpi_selector", "intel_hfi",
 		"opa_stack_dev",
 		"delta_ipoib",
-		"sandiashmem",
 		"delta_debug", );
 my @delta_Components_sles12_sp3 = ( "opa_stack", "intel_hfi",
 		"opa_stack_dev",
 		"delta_ipoib",
-		"sandiashmem",
 		"delta_debug", );
 my @delta_Components_sles12_sp4 = ( "opa_stack", "intel_hfi",
 		"opa_stack_dev",
 		"delta_ipoib",
-		"sandiashmem",
+		"delta_debug", );
+my @delta_Components_sles12_sp5 = ( "opa_stack", "intel_hfi",
+		"opa_stack_dev",
+		"delta_ipoib",
 		"delta_debug", );
 my @delta_Components_rhel74 = ( "opa_stack", "mpi_selector", "intel_hfi",
 		"opa_stack_dev",
 		"delta_ipoib",
-		"sandiashmem",
 		"delta_debug", );
 my @delta_Components_rhel75 = ( "opa_stack", "mpi_selector", "intel_hfi",
 		"opa_stack_dev",
 		"delta_ipoib",
-		"sandiashmem",
 		"delta_debug", );
 my @delta_Components_rhel76 = ( "opa_stack", "mpi_selector", "intel_hfi",
 		"opa_stack_dev",
 		"delta_ipoib",
-		"sandiashmem",
+		"delta_debug", );
+my @delta_Components_rhel77 = ( "opa_stack", "mpi_selector", "intel_hfi",
+		"opa_stack_dev",
+		"delta_ipoib",
+		"delta_debug", );
+my @delta_Components_rhel78 = ( "opa_stack", "mpi_selector", "intel_hfi",
+		"opa_stack_dev",
+		"delta_ipoib",
 		"delta_debug", );
 my @delta_Components_rhel8 = ( "opa_stack", "mpi_selector", "intel_hfi",
 		"opa_stack_dev",
 		"delta_ipoib",
-		"sandiashmem",
+		"delta_debug", );
+my @delta_Components_rhel81 = ( "opa_stack", "mpi_selector", "intel_hfi",
+		"opa_stack_dev",
+		"delta_ipoib",
+		"delta_debug", );
+my @delta_Components_rhel82 = ( "opa_stack", "mpi_selector", "intel_hfi",
+		"opa_stack_dev",
+		"delta_ipoib",
 		"delta_debug", );
 my @delta_Components_sles15 = ( "opa_stack", "intel_hfi",
 		"opa_stack_dev",
 		"delta_ipoib",
-		"sandiashmem",
 		"delta_debug", );
 my @delta_Components_sles15_sp1 = ( "opa_stack", "intel_hfi",
 		"opa_stack_dev",
 		"delta_ipoib",
-		"sandiashmem",
+		"delta_debug", );
+my @delta_Components_sles15_sp2 = ( "opa_stack", "intel_hfi",
+		"opa_stack_dev",
+		"delta_ipoib",
 		"delta_debug", );
 
 @Components = ( );
@@ -115,18 +128,30 @@ sub overrides()
 		@Components = ( @delta_Components_sles12_sp3 );
 	} elsif ( "$CUR_VENDOR_VER" eq "ES124" ) {
 		@Components = ( @delta_Components_sles12_sp4 );
+	} elsif ( "$CUR_VENDOR_VER" eq "ES125" ) {
+		@Components = ( @delta_Components_sles12_sp5 );
 	} elsif ( "$CUR_VENDOR_VER" eq "ES74" ) {
 		@Components = ( @delta_Components_rhel74 );
 	} elsif ( "$CUR_VENDOR_VER" eq "ES75" ) {
 		@Components = ( @delta_Components_rhel75 );
 	} elsif ( "$CUR_VENDOR_VER" eq "ES76" ) {
 		@Components = ( @delta_Components_rhel76 );
+	} elsif ( "$CUR_VENDOR_VER" eq "ES77" ) {
+		@Components = ( @delta_Components_rhel77 );
+	} elsif ( "$CUR_VENDOR_VER" eq "ES78" ) {
+		@Components = ( @delta_Components_rhel78 );
 	} elsif ( "$CUR_VENDOR_VER" eq "ES8" ) {
 		@Components = ( @delta_Components_rhel8 );
+	} elsif ( "$CUR_VENDOR_VER" eq "ES81" ) {
+		@Components = ( @delta_Components_rhel81 );
+	} elsif ( "$CUR_VENDOR_VER" eq "ES82" ) {
+		@Components = ( @delta_Components_rhel82 );
 	} elsif ( "$CUR_VENDOR_VER" eq "ES15" ) {
 		@Components = ( @delta_Components_sles15 );
 	} elsif ( "$CUR_VENDOR_VER" eq "ES151" ) {
 		@Components = ( @delta_Components_sles15_sp1 );
+	} elsif ( "$CUR_VENDOR_VER" eq "ES152" ) {
+		@Components = ( @delta_Components_sles15_sp2 );
 	} else {
 		# unsupported OS
 		@Components = ( );
