@@ -1,11 +1,11 @@
 #!/bin/bash
 # BEGIN_ICS_COPYRIGHT8 ****************************************
-# 
-# Copyright (c) 2015-2018, Intel Corporation
-# 
+#
+# Copyright (c) 2015-2020, Intel Corporation
+#
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
-# 
+#
 #     * Redistributions of source code must retain the above copyright notice,
 #       this list of conditions and the following disclaimer.
 #     * Redistributions in binary form must reproduce the above copyright
@@ -14,7 +14,7 @@
 #     * Neither the name of Intel Corporation nor the names of its contributors
 #       may be used to endorse or promote products derived from this software
 #       without specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
@@ -25,7 +25,7 @@
 # CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # END_ICS_COPYRIGHT8   ****************************************
 
 # [ICS VERSION STRING: unknown]
@@ -55,6 +55,7 @@ PCI_WIDTH="x16"             # expected value for PCI width on Intel WFR HFI
 MPI_APPS=$HOME/mpi_apps/    # where to find mpi_apps for HPL test
 MIN_FLOPS="115"             # minimum flops expected from HPL test
 IPOIB_IF="ib0"              # IPoIB interface to check
+IPOIB_MODE="connected"      # IPoIB required mode "connected" or "datagram"
 IPOIB_MTU=65520             # IPoIB required MTU
 outputdir=/root             # default outputdir is root -d $DIR overrides
 CPU_DRIVER="intel_pstate"   # power scaling driver for CPU
@@ -891,8 +892,8 @@ test_ipoib()
 	mtu=$(cat /sys/class/net/$IPOIB_IF/mtu)
 	mode=$(cat /sys/class/net/$IPOIB_IF/mode)
 	
-	[ $mode != "connected" ] && fail "$IPOIB_IF is in '$mode' mode - should be in 'connected' mode"
-	[ $mtu -lt $IPOIB_MTU ] && fail "$IPOIB_IF MTU of $mtu is less than required $IPOIB_MTU"
+	[ $mode != "$IPOIB_MODE" ] && fail "$IPOIB_IF is in '$mode' mode - should be in '$IPOIB_MODE' mode"
+	[ $mtu -ne $IPOIB_MTU ] && fail "$IPOIB_IF MTU of $mtu - should be $IPOIB_MTU"
 	set +x
 	
 	pass ": IPoIB properly configured"
