@@ -1,11 +1,11 @@
 #!/bin/bash
 # BEGIN_ICS_COPYRIGHT8 ****************************************
-# 
-# Copyright (c) 2015, Intel Corporation
-# 
+#
+# Copyright (c) 2015-2020, Intel Corporation
+#
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
-# 
+#
 #     * Redistributions of source code must retain the above copyright notice,
 #       this list of conditions and the following disclaimer.
 #     * Redistributions in binary form must reproduce the above copyright
@@ -14,7 +14,7 @@
 #     * Neither the name of Intel Corporation nor the names of its contributors
 #       may be used to endorse or promote products derived from this software
 #       without specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
@@ -25,7 +25,7 @@
 # CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
+#
 # END_ICS_COPYRIGHT8   ****************************************
 
 # [ICS VERSION STRING: unknown]
@@ -257,11 +257,11 @@ gen_switches()
 	suffix=":$hfi:$port"
 	export IFS=';'
 	rm -f $FILE_TEMP
-	eval $OPA_REPORT $port_opts -q -o comps -x -F nodetype:SW:port:0 -d 4| $XML_EXTRACT -H -d \; -e Node.NodeGUID -e Node.SystemImageGUID -e Node.Capability -e Node.PortInfo.Capability -e Node.NodeDesc -e Node.PortInfo.GUID -s Focus > $FILE_TEMP
+	eval $OPA_REPORT $port_opts -q -o comps -x -F nodetype:SW:port:0 -d 4| $XML_EXTRACT -H -d \; -e Node.LID -e Node.NodeGUID -e Node.SystemImageGUID -e Node.Capability -e Node.PortInfo.Capability -e Node.NodeDesc -e Node.PortInfo.GUID -s Focus > $FILE_TEMP
 	if [ $? -eq 0 ]
 	then
 		fl_write_switches=1
-		cat $FILE_TEMP | while read nodeguid systemguid capability portcapability nodedesc portguid
+		cat $FILE_TEMP | while read lid nodeguid systemguid capability portcapability nodedesc portguid
 		do
 			if [[ ! $portcapability =~ "VDR" ]]; then
 					continue
@@ -271,7 +271,8 @@ gen_switches()
 			comma=
 			if [ "$get_distance" = y ]
 			then
-				distance=$(eval opasaquery $port_opts -o trace -g $portguid | grep "NodeType: SW" | wc -l)
+				# Use lid to handle LMC != 0 case
+				distance=$(eval opasaquery $port_opts -o trace -l $lid | grep "NodeType: SW" | wc -l)
 				if [ ! -z "$distance" ]
 				then
 					comma=","
@@ -279,7 +280,7 @@ gen_switches()
 			fi
 
 			# valid names for switches start with a non-numeric and are alpha numeric
-			if [[ $nodedesc =~ ^[a-zA-Z_][a-zA-Z_0-9]*$ ]]
+			if [[ $nodedesc =~ ^[a-zA-Z_\-][a-zA-Z_0-9\-]*$ ]]
 			then
 				echo "$nodeguid$suffix,$nodedesc$comma$distance" >> $file_switches
 			else
