@@ -1,6 +1,6 @@
 /* BEGIN_ICS_COPYRIGHT7 ****************************************
 
-Copyright (c) 2015, Intel Corporation
+Copyright (c) 2015-2020, Intel Corporation
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:
@@ -9,7 +9,7 @@ modification, are permitted provided that the following conditions are met:
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
-     documentation and/or other materials provided with the distribution.
+      documentation and/or other materials provided with the distribution.
     * Neither the name of Intel Corporation nor the names of its contributors
       may be used to endorse or promote products derived from this software
       without specific prior written permission.
@@ -294,24 +294,24 @@ int main(int argc, char** argv)
 	char *p_arg2 = NULL;
 	char *p_arg3 = NULL;
 
-	if (argc >= 1)
+	if (argc > 1)
 	{
 		p_cmdname = argv[1];
-		if (argc >= 2)
+		if (argc > 2)
 		{
 			p_arg1 = argv[2];
 			if (!p_arg1) {
 				fprintf(stderr, "opagenswitches: Error: null input filename\n");
 				exit(status);
 			}
-			if (argc >= 3)
+			if (argc > 3)
 			{
 				p_arg2 = argv[3];
 				if (!p_arg2) {
 					fprintf(stderr, "opagenswitches: Error: null input filename\n");
 					exit(status);
 				}
-				if (argc >= 4)
+				if (argc > 4)
 				{
 					p_arg3 = argv[4];
 					if (!p_arg3) {
