@@ -39,7 +39,7 @@ ff_tools_sbin="opacabletest opacheckload opaextracterror opaextractlink
 	opaledports opaexpandfile opaextractbadlinks opaextractlids opaextractsellinks
 	opaextractmissinglinks opaswenableall opaswdisableall opaverifyhosts opahostadmin
 	opachassisadmin opaswitchadmin opapingall opascpall opasetupssh opashowallports
-	opauploadall opapaquery opashowmc opa2rm"
+	opauploadall opapaquery opashowmc opa2rm opaextractperf2 opamergeperf2"
 
 ff_tools_misc="ff_funcs opachassisip opagenswitcheshelper chassis_setup
 	switch_setup opagetipaddrtype opafastfabric.conf.def show_counts opacablehealthcron"
@@ -59,7 +59,7 @@ ff_mans="opaallanalysis.8 opacabletest.8 opacaptureall.8 opachassisadmin.8
 	opahostsmanalysis.8 opalinkanalysis.8 opapaquery.8 opapingall.8 opareport.8
 	opareports.8 opascpall.8 opasetupssh.8 opashowallports.8 opasorthosts.8
 	opaswitchadmin.8 opatop.8 opauploadall.8 opaverifyhosts.8 opaxlattopology.8
-	opashowmc.8 opaxmlextract.8 opaxmlfilter.8
+	opashowmc.8 opaxmlextract.8 opaxmlfilter.8 opaextractperf2.8 opamergeperf2.8 
 	opaxmlgenerate.8 opaxmlindent.8 opaswdisableall.8 opaswenableall.8
 	opafirmware.8 opaextractmissinglinks.8 opa2rm.8"
 
@@ -101,10 +101,6 @@ mpi_apps_files="Makefile mpi_hosts.sample README prepare_run select_mpi run_bw
 	run_multibw run_mpi_stress run_osu run_cabletest run_allhfilatency run_nxnlatbw
 	run_alltoall3 run_bcast3 run_bibw3 run_bw3 run_lat3 run_mbw_mr3 run_multi_lat3
 	run_batch_script run_batch_cabletest hpl-count.diff groupstress deviation
-	hpl-config/HPL.dat-* hpl-config/README mpicc mpif77"
+	hpl-config/HPL.dat-* hpl-config/README mpicc mpicxx mpif77"
 
-shmem_apps_files="Makefile mpi_hosts.sample prepare_run README select_mpi run_barrier
-	run_get_bibw run_get_bw run_get_latency run_put_bibw run_put_bw run_put_latency
-	run_reduce run_hello run_alltoall shmem-hello.c"
-
-opasnapconfig_bin="opasnapconfig"
+opasnapconfig_bin=
