@@ -1,6 +1,6 @@
 /* BEGIN_ICS_COPYRIGHT2 ****************************************
 
-Copyright (c) 2015-2017, Intel Corporation
+Copyright (c) 2015-2020, Intel Corporation
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:
@@ -303,12 +303,19 @@ iba_pa_query_master_pm_lid(struct omgt_port *port);
  *   FSUCCESS       - Get successfully
  *     FERROR       - Error
  */
-FSTATUS 
+FSTATUS
 iba_pa_multi_mad_group_list_response_query(
     IN struct omgt_port              *port,
     IN POMGT_QUERY                  query,
     OUT PQUERY_RESULT_VALUES        *pquery_result
     );
+FSTATUS
+iba_pa_multi_mad_group_list2_response_query(
+    IN struct omgt_port             *port,
+    IN POMGT_QUERY                  query,
+    IN STL_PA_IMAGE_ID_DATA         *image_id,
+    OUT PQUERY_RESULT_VALUES        *pquery_result
+    );
 
 /**
  *  Get multi-record response for pa group info (stats).
@@ -483,12 +490,19 @@ iba_pa_multi_mad_focus_ports_multiselect_response_query (
  *   FSUCCESS       - Get successfully
  *     FERROR       - Error
  */
-FSTATUS 
+FSTATUS
 iba_pa_multi_mad_vf_list_response_query(
-    IN struct omgt_port              *port,
+    IN struct omgt_port             *port,
     IN POMGT_QUERY                  query,
     OUT PQUERY_RESULT_VALUES        *pquery_result
     );
+FSTATUS
+iba_pa_multi_mad_vf_list2_response_query(
+    IN struct omgt_port             *port,
+    IN POMGT_QUERY                  query,
+    IN STL_PA_IMAGE_ID_DATA         *image_id,
+    OUT PQUERY_RESULT_VALUES        *pquery_result
+    );
 
 /**
  *  Get multi-record response for pa vf info (vf info).
